@@ -67,8 +67,8 @@ class Window(Adw.ApplicationWindow):
     stack_picture: Gtk.Stack = Gtk.Template.Child()
     status_welcome: Adw.StatusPage = Gtk.Template.Child()
     button_open: Gtk.Button = Gtk.Template.Child()
-    loading_page_spinner: Adw.Spinner = Gtk.Template.Child()  # type: ignore [name-defined]
-    loading_image_loading: Adw.Spinner = Gtk.Template.Child()  # type: ignore [name-defined]
+    loading_page_spinner: Adw.Spinner = Gtk.Template.Child()
+    loading_image_loading: Adw.Spinner = Gtk.Template.Child()
     # video = Gtk.Template.Child()
     combo_models: Adw.ComboRow = Gtk.Template.Child()
     string_models: Gtk.StringList = Gtk.Template.Child()
@@ -213,7 +213,7 @@ class Window(Adw.ApplicationWindow):
 
             self._set_post_upscale_image_size()
 
-            if self.main_nav_view.get_visible_page_tag() != "upscaling-options":  # type: ignore [attr-defined]
+            if self.main_nav_view.get_visible_page_tag() != "upscaling-options":
                 self.main_nav_view.push_by_tag("upscaling-options")
         finally:
             self.stop_loading_animation()
@@ -266,7 +266,7 @@ class Window(Adw.ApplicationWindow):
 
             self._set_post_upscale_image_size()
 
-            if self.main_nav_view.get_visible_page_tag() != "upscaling-options":  # type: ignore [attr-defined]
+            if self.main_nav_view.get_visible_page_tag() != "upscaling-options":
                 self.main_nav_view.push_by_tag("upscaling-options")
         finally:
             self.stop_loading_animation()
